import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface CloudSchedulerJobConfig extends TerraformMetaArguments {
    /**
     * The deadline for job attempts.
     *
     * If the request handler does not respond by this deadline then the request is
     * cancelled and the attempt is marked as a DEADLINE_EXCEEDED failure. The failed attempt can be viewed in
     * execution logs. Cloud Scheduler will retry the job according to the RetryConfig.
     * The allowed duration for this deadline is:
     * For HTTP targets, between 15 seconds and 30 minutes.
     * For App Engine HTTP targets, between 15 seconds and 24 hours.
     * **Note**: For PubSub targets, this field is ignored - setting it will introduce an unresolvable diff.
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s"
     */
    readonly attemptDeadline?: string;
    /**
     * A human-readable description for the job.
     *
     * This string must not contain more than 500 characters.
     */
    readonly description?: string;
    /**
     * The name of the job.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Region where the scheduler job resides.
     *
     * If it is not provided, Terraform will use the provider default.
     */
    readonly region?: string;
    /**
     * Describes the schedule on which the job will be executed.
     */
    readonly schedule?: string;
    /**
     * Specifies the time zone to be used in interpreting schedule.
     *
     * The value of this field must be a time zone name from the tz database.
     */
    readonly timeZone?: string;
    /**
     * app_engine_http_target block.
     */
    readonly appEngineHttpTarget?: CloudSchedulerJobAppEngineHttpTarget[];
    /**
     * http_target block.
     */
    readonly httpTarget?: CloudSchedulerJobHttpTarget[];
    /**
     * pubsub_target block.
     */
    readonly pubsubTarget?: CloudSchedulerJobPubsubTarget[];
    /**
     * retry_config block.
     */
    readonly retryConfig?: CloudSchedulerJobRetryConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: CloudSchedulerJobTimeouts;
}
/**
 *
 */
export interface CloudSchedulerJobAppEngineHttpTargetAppEngineRouting {
    /**
     * App instance.
     *
     * By default, the job is sent to an instance which is available when the job is attempted.
     */
    readonly instance?: string;
    /**
     * App service.
     *
     * By default, the job is sent to the service which is the default service when the job is attempted.
     */
    readonly service?: string;
    /**
     * App version.
     *
     * By default, the job is sent to the version which is the default version when the job is attempted.
     */
    readonly version?: string;
}
/**
 *
 */
export interface CloudSchedulerJobAppEngineHttpTarget {
    /**
     * HTTP request body.
     *
     * A request body is allowed only if the HTTP method is POST or PUT.
     * It will result in invalid argument error to set a body on a job with an incompatible HttpMethod.
     */
    readonly body?: string;
    /**
     * HTTP request headers.
     *
     * This map contains the header field names and values.
     * Headers can be set when the job is created.
     */
    readonly headers?: {
        [key: string]: string;
    };
    /**
     * Which HTTP method to use for the request.
     */
    readonly httpMethod?: string;
    /**
     * The relative URI.
     *
     * The relative URL must begin with "/" and must be a valid HTTP relative URL.
     * It can contain a path, query string arguments, and \# fragments.
     * If the relative URL is empty, then the root path "/" will be used.
     * No spaces are allowed, and the maximum length allowed is 2083 characters
     */
    readonly relativeUri: string;
    /**
     * app_engine_routing block.
     */
    readonly appEngineRouting?: CloudSchedulerJobAppEngineHttpTargetAppEngineRouting[];
}
/**
 *
 */
export interface CloudSchedulerJobHttpTargetOauthToken {
    /**
     * OAuth scope to be used for generating OAuth access token.
     *
     * If not specified,
     * "https://www.googleapis.com/auth/cloud-platform" will be used.
     */
    readonly scope?: string;
    /**
     * Service account email to be used for generating OAuth token.
     *
     * The service account must be within the same project as the job.
     */
    readonly serviceAccountEmail: string;
}
/**
 *
 */
export interface CloudSchedulerJobHttpTargetOidcToken {
    /**
     * Audience to be used when generating OIDC token.
     *
     * If not specified,
     * the URI specified in target will be used.
     */
    readonly audience?: string;
    /**
     * Service account email to be used for generating OAuth token.
     *
     * The service account must be within the same project as the job.
     */
    readonly serviceAccountEmail: string;
}
/**
 *
 */
export interface CloudSchedulerJobHttpTarget {
    /**
     * HTTP request body.
     *
     * A request body is allowed only if the HTTP method is POST, PUT, or PATCH.
     * It is an error to set body on a job with an incompatible HttpMethod.
     */
    readonly body?: string;
    /**
     * This map contains the header field names and values.
     *
     * Repeated headers are not supported, but a header value can contain commas.
     */
    readonly headers?: {
        [key: string]: string;
    };
    /**
     * Which HTTP method to use for the request.
     */
    readonly httpMethod?: string;
    /**
     * The full URI path that the request will be sent to.
     */
    readonly uri: string;
    /**
     * oauth_token block.
     */
    readonly oauthToken?: CloudSchedulerJobHttpTargetOauthToken[];
    /**
     * oidc_token block.
     */
    readonly oidcToken?: CloudSchedulerJobHttpTargetOidcToken[];
}
/**
 *
 */
export interface CloudSchedulerJobPubsubTarget {
    /**
     * Attributes for PubsubMessage.
     *
     * Pubsub message must contain either non-empty data, or at least one attribute.
     */
    readonly attributes?: {
        [key: string]: string;
    };
    /**
     * The message payload for PubsubMessage.
     *
     * Pubsub message must contain either non-empty data, or at least one attribute.
     */
    readonly data?: string;
    /**
     * The full resource name for the Cloud Pub/Sub topic to which messages will be published when a job is delivered.
     *
     * ~>**NOTE:**
     * The topic name must be in the same format as required by PubSub's
     * PublishRequest.name, e.g. 'projects/my-project/topics/my-topic'.
     */
    readonly topicName: string;
}
/**
 *
 */
export interface CloudSchedulerJobRetryConfig {
    /**
     * The maximum amount of time to wait before retrying a job after it fails.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     */
    readonly maxBackoffDuration?: string;
    /**
     * The time between retries will double maxDoublings times.
     *
     * A job's retry interval starts at minBackoffDuration,
     * then doubles maxDoublings times, then increases linearly,
     * and finally retries retries at intervals of maxBackoffDuration up to retryCount times.
     */
    readonly maxDoublings?: number;
    /**
     * The time limit for retrying a failed job, measured from time when an execution was first attempted.
     *
     * If specified with retryCount, the job will be retried until both limits are reached.
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     */
    readonly maxRetryDuration?: string;
    /**
     * The minimum amount of time to wait before retrying a job after it fails.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     */
    readonly minBackoffDuration?: string;
    /**
     * The number of attempts that the system will make to run a  job using the exponential backoff procedure described by maxDoublings.
     *
     * Values greater than 5 and negative values are not allowed.
     */
    readonly retryCount?: number;
}
/**
 *
 */
export interface CloudSchedulerJobTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class CloudSchedulerJob extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: CloudSchedulerJobConfig);
    private _attemptDeadline?;
    /**
     *
     */
    get attemptDeadline(): string;
    /**
     *
     */
    set attemptDeadline(value: string);
    /**
     *
     */
    resetAttemptDeadline(): void;
    /**
     *
     */
    get attemptDeadlineInput(): string | undefined;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _schedule?;
    /**
     *
     */
    get schedule(): string;
    /**
     *
     */
    set schedule(value: string);
    /**
     *
     */
    resetSchedule(): void;
    /**
     *
     */
    get scheduleInput(): string | undefined;
    private _timeZone?;
    /**
     *
     */
    get timeZone(): string;
    /**
     *
     */
    set timeZone(value: string);
    /**
     *
     */
    resetTimeZone(): void;
    /**
     *
     */
    get timeZoneInput(): string | undefined;
    private _appEngineHttpTarget?;
    /**
     *
     */
    get appEngineHttpTarget(): CloudSchedulerJobAppEngineHttpTarget[];
    /**
     *
     */
    set appEngineHttpTarget(value: CloudSchedulerJobAppEngineHttpTarget[]);
    /**
     *
     */
    resetAppEngineHttpTarget(): void;
    /**
     *
     */
    get appEngineHttpTargetInput(): CloudSchedulerJobAppEngineHttpTarget[] | undefined;
    private _httpTarget?;
    /**
     *
     */
    get httpTarget(): CloudSchedulerJobHttpTarget[];
    /**
     *
     */
    set httpTarget(value: CloudSchedulerJobHttpTarget[]);
    /**
     *
     */
    resetHttpTarget(): void;
    /**
     *
     */
    get httpTargetInput(): CloudSchedulerJobHttpTarget[] | undefined;
    private _pubsubTarget?;
    /**
     *
     */
    get pubsubTarget(): CloudSchedulerJobPubsubTarget[];
    /**
     *
     */
    set pubsubTarget(value: CloudSchedulerJobPubsubTarget[]);
    /**
     *
     */
    resetPubsubTarget(): void;
    /**
     *
     */
    get pubsubTargetInput(): CloudSchedulerJobPubsubTarget[] | undefined;
    private _retryConfig?;
    /**
     *
     */
    get retryConfig(): CloudSchedulerJobRetryConfig[];
    /**
     *
     */
    set retryConfig(value: CloudSchedulerJobRetryConfig[]);
    /**
     *
     */
    resetRetryConfig(): void;
    /**
     *
     */
    get retryConfigInput(): CloudSchedulerJobRetryConfig[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): CloudSchedulerJobTimeouts;
    /**
     *
     */
    set timeouts(value: CloudSchedulerJobTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): CloudSchedulerJobTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
